@@ -74,24 +74,27 @@ class Browser:
             driver = self.driver
         )
 
-    def where_id(self, id:str) -> 'ElementFinder':
-        return ElementFinder(
-            (By.ID, id),
-            self.driver
-        )
-
     def where_name(self, name:str) -> 'ElementFinder':
         return ElementFinder(
             (By.NAME, name),
             self.driver
         )
 
+    def where_id(self, id:str) -> 'ElementFinder':
+        return ElementFinder(
+            (By.ID, id),
+            self.driver
+        )
+
     def where_contain_text(self, text:str) -> 'ElementFinder':
         return ElementFinder.where_xpath(
             f"//*[contains(text(), '{text}')]",
             self.driver
         )
 
+    def where_inner_text(self, text:str) -> 'Elementfinder':
+        return ElementFinder.where_inner_text(text, self.driver)
+
     def where_class_name(self, name:str) -> 'ElementFinder':
         return ElementFinder(
             (By.CLASS_NAME, name),
